<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CloseFile</name>
    <message>
        <location filename="../CloseFileInit.js" line="+2"/>
        <source>&amp;Close</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Zamknij
&amp;Zamknij kartę</translatorcomment>
        <translation>Za&amp;mknij</translation>
    </message>
</context>
</TS>
